package com.zbf.system.service;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.zbf.system.domain.TOngoodsshelfBak;

/**
 * 入库任务历史Service接口
 *
 * @author tony
 * @date 2024-06-18
 */
public interface ITOngoodsshelfBakService
{
    /**
     * 查询入库任务历史
     *
     * @param id 入库任务历史主键
     * @return 入库任务历史
     */
    public TOngoodsshelfBak selectTOngoodsshelfBakById(String id);

    /**
     * 查询入库任务历史列表
     *
     * @param tOngoodsshelfBak 入库任务历史
     * @return 入库任务历史集合
     */
    public List<TOngoodsshelfBak> selectTOngoodsshelfBakList(TOngoodsshelfBak tOngoodsshelfBak);

    /**
     * 新增入库任务历史
     *
     * @param tOngoodsshelfBak 入库任务历史
     * @return 结果
     */
    public int insertTOngoodsshelfBak(TOngoodsshelfBak tOngoodsshelfBak);

    /**
     * 修改入库任务历史
     *
     * @param tOngoodsshelfBak 入库任务历史
     * @return 结果
     */
    public int updateTOngoodsshelfBak(TOngoodsshelfBak tOngoodsshelfBak);

    /**
     * 批量删除入库任务历史
     *
     * @param ids 需要删除的入库任务历史主键集合
     * @return 结果
     */
    public int deleteTOngoodsshelfBakByIds(String[] ids);

    /**
     * 删除入库任务历史信息
     *
     * @param id 入库任务历史主键
     * @return 结果
     */
    public int deleteTOngoodsshelfBakById(String id);

    /**
     * 批量禁用入库任务历史
     *
     * @param ids 需要禁用的入库任务历史主键集合
     * @return 结果
     */
    public int disabledTOngoodsshelfBakByIds(String[] ids);

    /**
     * 批量启用入库任务历史
     *
     * @param ids 需要启用的入库任务历史主键集合
     * @return 结果
     */
    public int enableTOngoodsshelfBakByIds(String[] ids);

    /**
     * 改变状态
     *
     * @param tOngoodsshelfBak
     * @return 结果
     */
    public int updateStatus(TOngoodsshelfBak tOngoodsshelfBak);

    List<TOngoodsshelfBak> list(LambdaQueryWrapper<TOngoodsshelfBak> tCkPickingwavegoodsBakLambdaQueryWrapper);

}

